@@ -1,12 +1,14 @@
 package Acme::CPANModules::PortedFrom::Clojure;
 
+use strict;
+
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-03-15'; # DATE
+our $DATE = '2023-10-31'; # DATE
 our $DIST = 'Acme-CPANModules-PortedFrom-Clojure'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 our $LIST = {
-    summary => "Modules/applications that are ported from (or inspired by) ".
+    summary => "List of modules/applications that are ported from (or inspired by) ".
         "Clojure",
     description => <<'_',
 
@@ -22,7 +24,7 @@ _
 };
 
 1;
-# ABSTRACT: Modules/applications that are ported from (or inspired by) Clojure
+# ABSTRACT: List of modules/applications that are ported from (or inspired by) Clojure
 
 __END__
 
@@ -32,21 +34,25 @@ __END__
 
 =head1 NAME
 
-Acme::CPANModules::PortedFrom::Clojure - Modules/applications that are ported from (or inspired by) Clojure
+Acme::CPANModules::PortedFrom::Clojure - List of modules/applications that are ported from (or inspired by) Clojure
 
 =head1 VERSION
 
-This document describes version 0.002 of Acme::CPANModules::PortedFrom::Clojure (from Perl distribution Acme-CPANModules-PortedFrom-Clojure), released on 2021-03-15.
+This document describes version 0.003 of Acme::CPANModules::PortedFrom::Clojure (from Perl distribution Acme-CPANModules-PortedFrom-Clojure), released on 2023-10-31.
 
 =head1 DESCRIPTION
 
 If you know of others, please drop me a message.
 
-=head1 ACME::MODULES ENTRIES
+=head1 ACME::CPANMODULES ENTRIES
 
 =over
 
-=item * L<String::CamelSnakeKebab> - camel-snake-kebab
+=item L<String::CamelSnakeKebab>
+
+camel-snake-kebab.
+
+Author: L<KABLAMO|https://metacpan.org/author/KABLAMO>
 
 =back
 
@@ -61,8 +67,13 @@ document CPAN. See L<Acme::CPANModules> for more details.
 =head2 What are ways to use this Acme::CPANModules module?
 
 Aside from reading this Acme::CPANModules module's POD documentation, you can
-install all the listed modules (entries) using L<cpanmodules> CLI (from
-L<App::cpanmodules> distribution):
+install all the listed modules (entries) using L<cpanm-cpanmodules> script (from
+L<App::cpanm::cpanmodules> distribution):
+
+ % cpanm-cpanmodules -n PortedFrom::Clojure
+
+Alternatively you can use the L<cpanmodules> CLI (from L<App::cpanmodules>
+distribution):
 
     % cpanmodules ls-entries PortedFrom::Clojure | cpanm -n
 
@@ -77,6 +88,8 @@ or directly:
 This Acme::CPANModules module also helps L<lcpan> produce a more meaningful
 result for C<lcpan related-mods> command when it comes to finding related
 modules for the modules listed in this Acme::CPANModules module.
+See L<App::lcpan::Cmd::related_mods> for more details on how "related modules"
+are found.
 
 =head1 HOMEPAGE
 
@@ -86,14 +99,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/Acme-CPANM
 
 Source repository is at L<https://github.com/perlancar/perl-Acme-CPANModules-PortedFrom-Clojure>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-Acme-CPANModules-PortedFrom-Clojure/issues>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 More on the same theme of modules ported from other languages:
@@ -111,11 +116,37 @@ L<cpanmodules> - CLI tool to let you browse/view the lists
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2020 by perlancar@cpan.org.
+This software is copyright (c) 2023, 2021, 2020 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Acme-CPANModules-PortedFrom-Clojure>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
